<h1>Admin Access</h1>

<h2>Impersonate An Author</h2>

<p>If an author requests to be switched off, or is unable to alter their
settings, use the 'Impersonate An Author' link and enter their PAUSEID.</p>
