[%
    title = 'Registration' ;

    crumb1_name = 'Registration' ;
%]

<div class="box">
    <p>Unfortunately this user account is locked, and is awaiting confirmation
    that it has been legitimately registered. If you registered this account,
    please check your email folders for a confirmation email from us. Click 
    the link within the email, and follow the instructions within the web 
    browser. Thank you.</p>
</div>
