[%
    title = 'Registration' ;

    crumb1_name = 'Registration' ;
%]

<div class="box">
    <p>Thank you for registering. An email has been sent to the email address
    you provided with a confirmation link. Please click the link, or copy it
    into a browser, to verify the email address. Thank you.</p>
</div>
