<h1>Author Preferences</h1>

<p>Use the menu on the left to select the types of preferences you would like 
to amend.</p>

<h2>Default Filter Settings</h2>

<p>Your default preferences are applied where you have no specific distribution
preferences, such as those distributions that you have recently uploaded, or
if you wish to have some or all of your distributions use the same set of
preferences.</p>

<h2>Distribution Filter Settings</h2>

<p>Upon selecting this option, a list of the distributions known to have been
released by you will be listed. Note that this page can take several minutes 
to load, as it reads multiple indices to verify the definitive list of 
distributions. Select a distribution and apply the preferences you would like
to have applied when a report for that distribution is received.</p>
